<?php
/*
Plugin Name:  DSK SEO
Version: 0.9.3
Author: Enrique Aguilar
Description: This plugin allows custom SEO Titles, Descriptions, and Keywords
*/

add_action( 'add_meta_boxes', 'dsk_seo_metabox' );
add_action( 'save_post', 'dsk_seo_save' );

function dsk_seo_metabox() {
	$thePostTypes = array( 'post', 'page' );
	foreach ($thePostTypes as $thePostType) {
		add_meta_box(
			'dsk_seo_section',
			__( 'SEO', 'dsk_seo_domain' ),
			'dsk_seo_mainfunc',
			$thePostType,
			'normal',
			'high'
		);
	}
}

function dsk_seo_mainfunc( $post ) {

	// Use nonce for verification
	wp_nonce_field( plugin_basename( __FILE__ ), 'dsk_seo_noncename' );
	$seo_title = get_post_meta( $post->ID, '_title', true );
	$seo_description = get_post_meta( $post->ID, '_description', true );
	$seo_keywords = get_post_meta( $post->ID, '_keywords', true );
?>
	<div class="dsk_seo"><label for="dsk_seo_title">Title:</label> <input type="text" id="dsk_seo_title" name="dsk_seo_title" value="<?php echo esc_attr($seo_title); ?>" /><div class="dsk_seo_goal" id="dsk_seo_title_goal"><span class="dsk_seo_count"></span> characters <span class="dsk_seo_tip">(70 is the recommended max)</span></div></div>
	<div class="dsk_seo"><label for="dsk_seo_description">Description:</label> <textarea id="dsk_seo_description" name="dsk_seo_description"><?php echo esc_attr($seo_description); ?></textarea><div class="dsk_seo_goal" id="dsk_seo_description_goal"><span class="dsk_seo_count"></span> characters <span class="dsk_seo_tip">(160 is the recommended max)</span></div></div>
	<div class="dsk_seo"><label for="dsk_seo_keywords">Keywords:</label> <input type="text" id="dsk_seo_keywords" name="dsk_seo_keywords" value="<?php echo esc_attr($seo_keywords); ?>" /><div class="dsk_seo_goal">Use commas to separate keywords.</div></div>
<?php
}

function dsk_seo_save( $post_id ) {
	if(!isset($_REQUEST['post_type'])) {return;}

	if ( 'page' == $_REQUEST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {return;}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {return;}
	}

	// Secondly we need to check if the user intended to change this value.
	if ( ! isset( $_POST['dsk_seo_noncename'] ) || ! wp_verify_nonce( $_POST['dsk_seo_noncename'], plugin_basename( __FILE__ ) ) )
	  return;

	// Thirdly we can save the value to the database

	//if saving in a custom table, get post_ID
	$post_ID = $_POST['post_ID'];

	$seo_title = sanitize_text_field( $_POST['dsk_seo_title'] );
	update_post_meta($post_ID, '_title', $seo_title);

	$seo_description = sanitize_text_field( $_POST['dsk_seo_description'] );
	update_post_meta($post_ID, '_description', $seo_description);

	$seo_keywords = sanitize_text_field( $_POST['dsk_seo_keywords'] );
	update_post_meta($post_ID, '_keywords', $seo_keywords);

}

function dsk_seo_enqueue($hook) {
    if( 'post.php' != $hook && 'post-new.php' != $hook ) return;
 	wp_register_style( 'dsk_seo_css', plugins_url('/css/style.css', __FILE__ ), false, '1.0.0' );
	wp_register_script( 'dsk_seo_script', plugins_url('/js/script.js', __FILE__), array('jquery'), '1.0.0' );
	wp_enqueue_style( 'dsk_seo_css' );
	wp_enqueue_script( 'dsk_seo_script' );
}
add_action( 'admin_enqueue_scripts', 'dsk_seo_enqueue' );

function dsk_seo_title($title, $sep) {
	global $post;
	$seo_title = get_post_meta( $post->ID, '_title', true );
	$siteName = get_bloginfo( 'name' );
	if( $seo_title == '' ) {
		$title = "$title $siteName";
	} else {
		$title = $seo_title;
	}
//	$title = htmlentities($title);
	return $title;
}
add_filter( 'wp_title', 'dsk_seo_title', 99, 2 );

function dsk_seo_metas() {
	global $post;
	$seo_description = get_post_meta( $post->ID, '_description', true );
	if($seo_description == '') {
			$tempContent = $post->post_content;
            $tempContent = strip_tags($tempContent);
            $tempContent = substr($tempContent,0,160);
			$tempContent = str_ireplace("\r\n", "\n", $tempContent);
			$tempContent = str_ireplace("\r", "\n", $tempContent);
			$tempContent = str_ireplace("\n", " ", $tempContent);
            $lastSpacePos = strripos($tempContent, " ");
            $tempContent = substr($tempContent, 0, $lastSpacePos);
			$seo_description = $tempContent . "...";
	}

	if($seo_description != '') {
//		$seo_description = htmlentities($seo_description);
	?>
		<meta name="description" content="<?php echo $seo_description; ?>" />
<?php
	}
	$seo_keywords = get_post_meta( $post->ID, '_keywords', true );
	if($seo_keywords != '') {
//		$seo_keywords = htmlentities($seo_keywords);
	 ?>
		<meta name="keywords" content="<?php echo $seo_keywords; ?>" />
<?php
	}
}
add_action('wp_head', 'dsk_seo_metas');
?>